@@ -32,6 +32,7 @@
 # -arr.col       Color of the arrows, pass to `shape::Arrowhead`.
 # -arr.lwd       Line width of arrows, pass to `shape::Arrowhead`.
 # -arr.lty       Line type of arrows, pass to `shape::Arrowhead`.
+# -reduce_to_mid_line Only use the middle points of ``point1`` and ``point2`` to draw the link.
 #
 # == details
 # Links are implemented as quadratic Bezier curves (https://en.wikipedia.org/wiki/B\%C3\%A9zier_curve#Rational_B.C3.A9zier_curves ).
@@ -69,7 +70,8 @@ circos.link = function(
     arr.type = "triangle",
     arr.lty = lty,
     arr.lwd = lwd,
-    arr.col = col) {
+    arr.col = col,
+    reduce_to_mid_line = FALSE) {
 
     sector.data1 = get.sector.data(sector.index1)
     sector.data2 = get.sector.data(sector.index2)
@@ -77,6 +79,11 @@ circos.link = function(
 	point1 = sort(point1)
 	point2 = sort(point2)
 
+	if(reduce_to_mid_line) {
+		point1 = mean(point1)
+		point2 = mean(point2)
+	}
+
     if(length(point1) == 1 && length(point2) == 1) {  # single line
         theta1 = circlize(point1, 0, sector.index = sector.index1, track.index = 0)[1, "theta"]
         theta2 = circlize(point2, 0, sector.index = sector.index2, track.index = 0)[1, "theta"]
@@ -506,6 +513,17 @@ quadratic.bezier.length = function(p0, p1, p2, w = 1) {
 
 }
 
+# quadratic.bezier = function(p0, p1, p2, w = 1) {
+# 	ncut = bezier::bezierArcLength(p = rbind(p0, p1, p2), 0, 1)$arc.length/ (2*pi/circos.par("unit.circle.segments"))
+# 	ncut = floor(ncut)
+# 	ncut = ifelse(ncut < 3, 3, ncut)
+# 	if(ncut %% 2 == 0) ncut = ncut + 1  # odd number
+
+# 	t = seq(0, 1, length.out = ncut)
+# 	p = rbind(p0, c(p0[1]*0.5, p0[2]), p1, c(p2[1]*0.5, p2[2]), p2)
+# 	bezier::bezier(t, p)
+# }
+
 are.lines.intersected = function(x1, y1, x2, y2) {
 	n1 = length(x1)
 	n2 = length(x2)
